import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DatabaseMigrationServiceClient";
import { DescribeEndpointTypesMessage, DescribeEndpointTypesResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeEndpointTypesCommand}.
 */
export interface DescribeEndpointTypesCommandInput extends DescribeEndpointTypesMessage {
}
/**
 * @public
 *
 * The output of {@link DescribeEndpointTypesCommand}.
 */
export interface DescribeEndpointTypesCommandOutput extends DescribeEndpointTypesResponse, __MetadataBearer {
}
declare const DescribeEndpointTypesCommand_base: {
    new (input: DescribeEndpointTypesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeEndpointTypesCommandInput, DescribeEndpointTypesCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeEndpointTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeEndpointTypesCommandInput, DescribeEndpointTypesCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns information about the type of endpoints available.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DatabaseMigrationServiceClient, DescribeEndpointTypesCommand } from "@aws-sdk/client-database-migration-service"; // ES Modules import
 * // const { DatabaseMigrationServiceClient, DescribeEndpointTypesCommand } = require("@aws-sdk/client-database-migration-service"); // CommonJS import
 * const client = new DatabaseMigrationServiceClient(config);
 * const input = { // DescribeEndpointTypesMessage
 *   Filters: [ // FilterList
 *     { // Filter
 *       Name: "STRING_VALUE", // required
 *       Values: [ // FilterValueList // required
 *         "STRING_VALUE",
 *       ],
 *     },
 *   ],
 *   MaxRecords: Number("int"),
 *   Marker: "STRING_VALUE",
 * };
 * const command = new DescribeEndpointTypesCommand(input);
 * const response = await client.send(command);
 * // { // DescribeEndpointTypesResponse
 * //   Marker: "STRING_VALUE",
 * //   SupportedEndpointTypes: [ // SupportedEndpointTypeList
 * //     { // SupportedEndpointType
 * //       EngineName: "STRING_VALUE",
 * //       SupportsCDC: true || false,
 * //       EndpointType: "source" || "target",
 * //       ReplicationInstanceEngineMinimumVersion: "STRING_VALUE",
 * //       EngineDisplayName: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeEndpointTypesCommandInput - {@link DescribeEndpointTypesCommandInput}
 * @returns {@link DescribeEndpointTypesCommandOutput}
 * @see {@link DescribeEndpointTypesCommandInput} for command's `input` shape.
 * @see {@link DescribeEndpointTypesCommandOutput} for command's `response` shape.
 * @see {@link DatabaseMigrationServiceClientResolvedConfig | config} for DatabaseMigrationServiceClient's `config` shape.
 *
 * @throws {@link DatabaseMigrationServiceServiceException}
 * <p>Base exception class for all service exceptions from DatabaseMigrationService service.</p>
 *
 * @public
 * @example Describe endpoint types
 * ```javascript
 * // Returns information about the type of endpoints available.
 * const input = {
 *   "Filters": [
 *     {
 *       "Name": "string",
 *       "Values": [
 *         "string",
 *         "string"
 *       ]
 *     }
 *   ],
 *   "Marker": "",
 *   "MaxRecords": 123
 * };
 * const command = new DescribeEndpointTypesCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "Marker": "",
 *   "SupportedEndpointTypes": []
 * }
 * *\/
 * // example id: describe-endpoint-types-1481754742591
 * ```
 *
 */
export declare class DescribeEndpointTypesCommand extends DescribeEndpointTypesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeEndpointTypesMessage;
            output: DescribeEndpointTypesResponse;
        };
        sdk: {
            input: DescribeEndpointTypesCommandInput;
            output: DescribeEndpointTypesCommandOutput;
        };
    };
}
